@@ -89,18 +89,18 @@ class Experiment:
         self.Pumps.pump_vacuum(6, 0.1)
 
     def start_experiment(self):
-        if self.experiment_thread is None:
+        if self.is_running():
+            print("Experiment thread is already running! Use pe.stop_experiment() to stop.")
+        else:
             self.experiment_thread = threading.Thread(target=start_experiment, args=(self,))
             self.experiment_thread.daemon = True
             self.experiment_thread.start()
 
-        else:
-            if self.experiment_thread.is_alive():
-                print("Experiment thread is already running! Use pe.stop_experiment() to stop.")
-            else:
-                self.experiment_thread = threading.Thread(target=start_experiment, args=(self,))
-                self.experiment_thread.daemon = True
-                self.experiment_thread.start()
+    def is_running(self):
+        try:
+            return self.experiment_thread.is_alive()
+        except AttributeError:
+            return False
 
 
     def stop_experiment(self):
@@ -119,5 +119,3 @@ class Experiment:
     def read_parameters_OD_thresholds(self):
         return read_parameters_OD_thresholds(self)
 
-    def is_running(self):
-        return self.experiment_thread.is_alive()
